View Source t__repository (t__ v0.1.0)

Link to this section Summary

Functions

Return the ETS table holding information for the specified application repository
Update the specified repository (only if file changes are detected).
Update the application repository

Link to this section Functions

Link to this function

ets_table(Application, RepositoryName)

-spec ets_table(Application, RepositoryName) -> TableName
             when
                 Application :: string() | binary() | atom(),
                 RepositoryName :: string() | binary() | atom(),
                 TableName :: string().
Return the ETS table holding information for the specified application repository
Link to this function

update(Application, Repository)

-spec update(Application, Repository) -> {ok, NewRepository} | {error, Error}
          when
              Application :: atom(),
              Repository :: t__:repository(),
              NewRepository :: t__:repository(),
              Error :: term().
Update the specified repository (only if file changes are detected).
Link to this function

update_force(Application, Repository)

-spec update_force(Application, Repository) -> {ok, NewRepository} | {error, Error}
                when
                    Application :: atom(),
                    Repository :: t__:repository(),
                    NewRepository :: t__:repository(),
                    Error :: term().
Update the application repository